@@ -4,32 +4,30 @@ from operator import attrgetter
 import re
 from typing import Iterable, TYPE_CHECKING
 
-from six import add_metaclass
-from six.moves import filter
-
 
 if TYPE_CHECKING:
     from wsgi_lineprof.stats import LineProfilerStat
 
 
-@add_metaclass(ABCMeta)
-class BaseFilter(object):
+class BaseFilter(metaclass=ABCMeta):
     @abstractmethod
-    def filter(self, stats):
-        # type: (Iterable[LineProfilerStat]) -> Iterable[LineProfilerStat]
+    def filter(
+        self, stats: Iterable["LineProfilerStat"]
+    ) -> Iterable["LineProfilerStat"]:
         pass
 
 
 class FilenameFilter(BaseFilter):
     """Filter which matches with filename"""
-    def __init__(self, filename, regex=False):
-        # type: (str, bool) -> None
+
+    def __init__(self, filename: str, regex: bool = False) -> None:
         self.filename = filename
         self.regex = regex
         self.compiled_regex = re.compile(filename)
 
-    def filter(self, stats):
-        # type: (Iterable[LineProfilerStat]) -> Iterable[LineProfilerStat]
+    def filter(
+        self, stats: Iterable["LineProfilerStat"]
+    ) -> Iterable["LineProfilerStat"]:
         if self.regex:
             compiled_regex = self.compiled_regex
             return filter(lambda s: compiled_regex.search(s.filename), stats)
@@ -39,14 +37,15 @@ class FilenameFilter(BaseFilter):
 
 class NameFilter(BaseFilter):
     """Filter which matches with name"""
-    def __init__(self, name, regex=True):
-        # type: (str, bool) -> None
+
+    def __init__(self, name: str, regex: bool = True) -> None:
         self.name = name
         self.regex = regex
         self.compiled_regex = re.compile(name)
 
-    def filter(self, stats):
-        # type: (Iterable[LineProfilerStat]) -> Iterable[LineProfilerStat]
+    def filter(
+        self, stats: Iterable["LineProfilerStat"]
+    ) -> Iterable["LineProfilerStat"]:
         if self.regex:
             compiled_regex = self.compiled_regex
             return filter(lambda s: compiled_regex.search(s.name), stats)
@@ -56,22 +55,23 @@ class NameFilter(BaseFilter):
 
 class TotalTimeSorter(BaseFilter):
     """Sort stats by total time"""
-    def __init__(self, reverse=True):
-        # type: (bool) -> None
+
+    def __init__(self, reverse: bool = True) -> None:
         self.reverse = reverse
 
-    def filter(self, stats):
-        # type: (Iterable[LineProfilerStat]) -> Iterable[LineProfilerStat]
-        return sorted(stats,
-                      key=attrgetter("total_time"), reverse=self.reverse)
+    def filter(
+        self, stats: Iterable["LineProfilerStat"]
+    ) -> Iterable["LineProfilerStat"]:
+        return sorted(stats, key=attrgetter("total_time"), reverse=self.reverse)
 
 
 class TopItemsFilter(BaseFilter):
     """Get first n stats"""
-    def __init__(self, n=10):
-        # type: (int) -> None
+
+    def __init__(self, n: int = 10) -> None:
         self.n = n
 
-    def filter(self, stats):
-        # type: (Iterable[LineProfilerStat]) -> Iterable[LineProfilerStat]
+    def filter(
+        self, stats: Iterable["LineProfilerStat"]
+    ) -> Iterable["LineProfilerStat"]:
         return islice(stats, self.n)
